@@ -1,6 +1,7 @@
 """Root module for jsonvl."""
+from jsonvl.core.constraint import Constraint
 from jsonvl.core.validation import validate, validate_file
 from jsonvl.core.validator import Validator
 
 
-__all__ = ['Validator', 'validate', 'validate_file']
+__all__ = ['Constraint', 'Validator', 'validate', 'validate_file']
